@@ -67,9 +67,7 @@ class Mongo:
 
             writer = self.client[database][collection]
             result = writer.insert_many(queries)
-            print(
-                f"Successfully inserted {len(queries)} documents to '{database}'-'{collection}'"
-            )
+            # print(f"Successfully inserted {len(queries)} documents to '{database}'-'{collection}'")
             return result.inserted_ids
         except Exception as err:
             raise Exception("ERROR - Inserting to MongoClient:", err)
@@ -82,7 +80,7 @@ class Mongo:
 
             writer = self.client[database][collection]
             result = writer.insert_one(query)
-            print(f"Successfully inserted document to '{database}'-'{collection}'")
+            # print(f"Successfully inserted document to '{database}'-'{collection}'")
             return result.inserted_id
         except Exception as err:
             raise Exception("ERROR - Inserting to MongoClient:", err)
