@@ -311,13 +311,64 @@ class UnleashAdmin:
             print("REQEUST ERROR:", err)
             raise
 
+    def mark_stale_feature_toggle(self, feature_name):
+        """
+        Used to mark a feature toggle as stale
+        """
+        url = f"{self.admin_uri}/features/{feature_name}/stale/on"
+        try:
+            res = requests.post(url=url, headers=self.headers)
+            res.raise_for_status()
+            return res.json()
+        except requests.exceptions.HTTPError as errh:
+            print("HTTP ERROR:", errh)
+            raise
+        except requests.exceptions.ConnectionError as errc:
+            print("CONNECTION ERROR:", errc)
+            raise
+        except requests.exceptions.Timeout as errt:
+            print("TIMEOUT ERROR:", errt)
+            raise
+        except requests.exceptions.RequestException as err:
+            print("REQEUST ERROR:", err)
+            raise
+
+    def mark_active_feature_toggle(self, feature_name):
+        """
+        Used to mark a feature toggle as active
+        """
+        url = f"{self.admin_uri}/features/{feature_name}/stale/off"
+        try:
+            res = requests.post(url=url, headers=self.headers)
+            res.raise_for_status()
+            return res.json()
+        except requests.exceptions.HTTPError as errh:
+            print("HTTP ERROR:", errh)
+            raise
+        except requests.exceptions.ConnectionError as errc:
+            print("CONNECTION ERROR:", errc)
+            raise
+        except requests.exceptions.Timeout as errt:
+            print("TIMEOUT ERROR:", errt)
+            raise
+        except requests.exceptions.RequestException as err:
+            print("REQEUST ERROR:", err)
+            raise
+
 
 class UnleashClient:
-    def __init__(self, address, auth_token, app_name):
+    def __init__(
+        self,
+        address,
+        auth_token,
+        app_name,
+        refresh_interval=15,
+    ):
         self.client = unleash_client(
             url=f"{address}/api",
             app_name=app_name,
             custom_headers={"Authorization": auth_token},
+            refresh_interval=refresh_interval,
         )
         self.client.initialize_client()
 
